Configuration
=============

Setting up a slidge component
-----------------------------

Refer to the `slidge admin docs <https://slidge.im/docs/slidge/main/admin>`_ for generic
instructions on how to set up a slidge component, and for slidge core
configuration options.

messlidger-specific config
--------------------------

.. config-obj:: messlidger.config
